@@ -1,4 +1,5 @@
 from typing import List
+from unittest.mock import patch
 
 import astroid
 import pytest
@@ -125,6 +126,46 @@ container_list = [
         '''
         pass
     """,
+    """
+    def in_empty_set(x: int):
+        '''
+        Preconditions:
+            - x in set()
+        '''
+        pass
+    """,
+    """
+    def not_in_empty_set(x: int):
+        '''
+        Preconditions:
+            - x not in set()
+        '''
+        pass
+    """,
+    """
+    def in_set_call_with_args(x: int):
+        '''
+        Preconditions:
+            - x in set([1, 2])
+        '''
+        pass
+    """,
+    """
+    def in_list_call_with_args(x: int):
+        '''
+        Preconditions:
+            - x in list((3, 4))
+        '''
+        pass
+    """,
+    """
+    def not_in_tuple_call_with_args(x: int):
+        '''
+        Preconditions:
+            - x not in tuple([5, 6])
+        '''
+        pass
+    """,
 ]
 
 # test cases for strings expressions
@@ -236,6 +277,11 @@ container_expected = [
     [z3.BoolVal(False)],
     [z3.BoolVal(True)],
     [z3.BoolVal(True)],
+    [z3.BoolVal(False)],
+    [z3.BoolVal(True)],
+    [z3.Or(x == 1, x == 2)],
+    [z3.Or(x == 3, x == 4)],
+    [z3.And(x != 5, x != 6)],
 ]
 
 # expected string expressions
@@ -362,7 +408,7 @@ def test_cfg_z3_vars_initialization():
     """
     node = astroid.extract_node(z3_vars_example)
 
-    cfg = ControlFlowGraph()
+    cfg = ControlFlowGraph(z3_enabled=True)
     cfg.add_arguments(node.args)
 
     assert len(cfg.z3_vars) == 4
@@ -370,3 +416,13 @@ def test_cfg_z3_vars_initialization():
     assert cfg.z3_vars["y"] == z3.Real("y")
     assert cfg.z3_vars["z"] == z3.Bool("z")
     assert cfg.z3_vars["a"] == z3.String("a")
+
+
+@patch.dict("sys.modules", {"python_ta.z3.z3_parser": None})
+def test_cfg_z3_initialization_failed_import(caplog) -> None:
+    """Test verifies if `add_argument` handles import error as expected."""
+    node = astroid.extract_node(z3_vars_example)
+    cfg = ControlFlowGraph(z3_enabled=True)
+    cfg.add_arguments(node.args)
+
+    assert "Failed to import Z3Parser" in caplog.text
